
#pragma once

#include "SlateWidgetStyleContainerBase.h"
#include "SkillButtonStyle.h"
#include "SkillsPanelStyle.generated.h"

/**
* Represents the appearance of an SShooterScoreboardWidget
*/
USTRUCT()
struct GUILIBRARY_API FSkillsPanelWidgetStyle : public FSlateWidgetStyle
{
	GENERATED_USTRUCT_BODY()

	FSkillsPanelWidgetStyle();
	virtual ~FSkillsPanelWidgetStyle();

	// FSlateWidgetStyle
	virtual void GetResources(TArray<const FSlateBrush*>& OutBrushes) const override;
	static const FName TypeName;
	virtual const FName GetTypeName() const override{ return TypeName; };
	static const FSkillsPanelWidgetStyle& GetDefault();

	/** Background brush of this Skills Panel. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush BackgroundBrush;
	FSkillsPanelWidgetStyle& SetBackgroundBrush(const FSlateBrush& InItemBorderBrush) { BackgroundBrush = InItemBorderBrush; return *this; }

	/** General padding from Panel border to buttons list. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FMargin ContentPadding;
	FSkillsPanelWidgetStyle& SetContentPadding(const FMargin& InContentPadding) { ContentPadding = InContentPadding; return *this; }

	/** Padding between buttons. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FMargin SlotPadding;
	FSkillsPanelWidgetStyle& SetSlotPadding(const FMargin& InSlotPadding) { SlotPadding = InSlotPadding; return *this; }

	/** Minimal height of one slot. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	float MinSlotHeight;
	FSkillsPanelWidgetStyle& SetMinSlotHeight(const float& InMinSlotHeight) { MinSlotHeight = InMinSlotHeight; return *this; }

	/** Minimal width of one slot. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	float MinSlotWidth;
	FSkillsPanelWidgetStyle& SetMinSlotWidth(const float& InMinSlotWidth) { MinSlotWidth = InMinSlotWidth; return *this; }

	/** Border brush of the button. Use it if you want all buttons to have same border. */
	UPROPERTY(EditAnywhere, Category = Appearance)
	FSlateBrush ButtonBorderBrush;
	FSkillsPanelWidgetStyle& SetButtonBorderBrush(const FSlateBrush& InButtonBorderBrush) { ButtonBorderBrush = InButtonBorderBrush; return *this; }

	/** Buttons styles that will be added through code. If left empty, buttons will use style defined by ButtonStyle below.
	* Example: if you will add 5 buttons (button_1, button_2, ...) to this panel,
	* Styles from this array will be applied to corresponding buttons like this:
	* button_1.Style = SkillButtonStyles[0];
	* button_2.Style = SkillButtonStyles[1];
	* button_3.Style = SkillButtonStyles[2];
	* And so on... */
	UPROPERTY(EditAnywhere, Category = "Button Styles")
	TArray<USlateWidgetStyleAsset*> SkillButtonStyles;

	/** Default Button style that will be used if no style was found in SkillButtonStyles. */
	UPROPERTY(EditAnywhere, Category = "Button Styles")
	FSkillButtonWidgetStyle ButtonStyle;

	/** Content padding of this button. Used only if content is set (when creating button from command info). */
	UPROPERTY(EditAnywhere, Category = "Advanced")
	FMargin ButtonContentPadding;

	/** Should buttons in this panel draw hotkey text? */
	UPROPERTY(EditAnywhere, Category = "Advanced")
	bool bDrawHotkeyText;

	/** Should hotkey text be visible only on mouse hover? */
	UPROPERTY(EditAnywhere, Category = "Advanced")
	bool bDrawHotkeyTextOnHover;

	/** Should we draw hotkey text inside the button? */
	UPROPERTY(EditAnywhere, Category = "Advanced", meta = (editcondition = "bDrawHotkeyText"))
	bool bHotkeyTextInsideButton;

	/** Background brush for hotkey text. Used only if bDrawHotkeyText is true. */
	UPROPERTY(EditAnywhere, Category = "Advanced")
	FSlateBrush HotkeyTextBorderBrush;
	FSkillsPanelWidgetStyle& SetItemBorderBrush(const FSlateBrush& InHotkeyTextBorderBrush) { HotkeyTextBorderBrush = InHotkeyTextBorderBrush; return *this; }

	

};


/**
*/
UCLASS(hidecategories = Object, MinimalAPI)
class USkillsPanelStyle : public USlateWidgetStyleContainerBase
{
	GENERATED_UCLASS_BODY()

public:
	/** The actual data describing the scoreboard's appearance. */
	UPROPERTY(Category = Appearance, EditAnywhere, meta = (ShowOnlyInnerProperties))
		FSkillsPanelWidgetStyle ResourceBarStyle;

	virtual const struct FSlateWidgetStyle* const GetStyle() const override
	{
		return static_cast< const struct FSlateWidgetStyle* >(&ResourceBarStyle);
	}
};
